==> haskell-neat-interpolation-0.5.1.2-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 neat-interpolation
version:              0.5.1.2
visibility:           public
id:                   neat-interpolation-0.5.1.2-BRVwTnd72ctLMDWosRrfcr
key:                  neat-interpolation-0.5.1.2-BRVwTnd72ctLMDWosRrfcr
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    A quasiquoter for neat and simple multiline text interpolation

description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  f87fa5ff8fd366b95aed89404cffad94
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-8.10.4/site-local/neat-interpolation-0.5.1.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/neat-interpolation-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/neat-interpolation-0.5.1.2

hs-libraries:         HSneat-interpolation-0.5.1.2-BRVwTnd72ctLMDWosRrfcr
depends:
    base-4.14.1.0 megaparsec-9.0.1-LNIiYWqJqEXGvr6cpFD2t0
    template-haskell-2.16.0.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.5.1.2-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 neat-interpolation
version:              0.5.1.2
visibility:           public
id:                   neat-interpolation-0.5.1.2-HAD29mN3OyH6rQP5VPyOT1
key:                  neat-interpolation-0.5.1.2-HAD29mN3OyH6rQP5VPyOT1
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    A quasiquoter for neat and simple multiline text interpolation

description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  d398ab4cfcc58f1d3f97ace9af8ed6e8
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-8.10.4/site-local/neat-interpolation-0.5.1.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/neat-interpolation-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/neat-interpolation-0.5.1.2

hs-libraries:         HSneat-interpolation-0.5.1.2-HAD29mN3OyH6rQP5VPyOT1
depends:
    base-4.14.1.0 megaparsec-9.0.1-HPcytxEBjca7iGrJm4jhhK
    template-haskell-2.16.0.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
